bl_info = {
    "name": "Sync_Image",
    "author": "pepe",
    "version": (1, 1, 0),
    "blender": (2, 93, 0),
    "location": "Shader Editor",
    "description": "Sync image in UV Editor with selected Shader Image Node",
    "wiki_url": "",
    "category": "Shader Editor"}
    
# After installation a SYNC button apper in the Shader Editor
# Select the image node and press SYNC button to have the corespond image in UV Editor or Image Editor    
    

import bpy


class SYNC_image(bpy.types.Operator):
    bl_idname = "image.synced"
    bl_label = "SYNC"
    bl_description = "Sync image in UV Editor or Image Editor with selected Shader Image Node"
    bl_options = {"REGISTER"}

    def execute(self, context):
        

        for a in bpy.context.screen.areas:
            if a.type == 'IMAGE_EDITOR':
                space = a.spaces[0]
                
                mat = bpy.context.view_layer.objects.active.active_material
                mat_name = bpy.context.active_object.active_material.name
                mat.use_nodes = True
                
                if bpy.context.scene.render.engine == 'CYCLES':
                    image_node = mat.node_tree.nodes.active
                elif bpy.context.scene.render.engine == 'BLENDER_EEVEE':
                    image_node = mat.node_tree.nodes.active
                elif bpy.context.scene.render.engine == 'BLENDER_WORKBENCH':
                    image_node = mat.node_tree.nodes.active
                elif bpy.context.scene.render.engine == 'LUXCORE':
                    image_node = mat.luxcore.node_tree.nodes.active
                
                if hasattr(image_node,"image"):
                    txtr = image_node.image.name
                    space.image = bpy.data.images[txtr]
                else:
                    self.report({"WARNING"}, "No image attribute for this node")
                
        return {"FINISHED"}


def draw(self, context):
    self.layout.operator(SYNC_image.bl_idname)


classes = (SYNC_image,)


def register():
    for cls in classes:
        bpy.utils.register_class(cls)
        
    bpy.types.NODE_HT_header.prepend(draw) # use 'append' to add the bttn to the right end in the header


def unregister():
    bpy.types.NODE_HT_header.remove(draw)
    
    for cls in classes:
        bpy.utils.unregister_class(cls)


if __name__ == "__main__":
    register()